@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class NomadProvider(
-    cdktf.TerraformProvider,
+    _cdktf_9a9027ec.TerraformProvider,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-nomad.provider.NomadProvider",
 ):
@@ -30,7 +30,7 @@ class NomadProvider(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         address: builtins.str,
@@ -40,9 +40,9 @@ class NomadProvider(
         cert_file: typing.Optional[builtins.str] = None,
         cert_pem: typing.Optional[builtins.str] = None,
         consul_token: typing.Optional[builtins.str] = None,
-        headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[str, typing.Any]]]]] = None,
+        headers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[builtins.str, typing.Any]]]]] = None,
         http_auth: typing.Optional[builtins.str] = None,
-        ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]] = None,
+        ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]] = None,
         key_file: typing.Optional[builtins.str] = None,
         key_pem: typing.Optional[builtins.str] = None,
         region: typing.Optional[builtins.str] = None,
@@ -70,28 +70,7 @@ class NomadProvider(
         :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#vault_token NomadProvider#vault_token}
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                address: builtins.str,
-                alias: typing.Optional[builtins.str] = None,
-                ca_file: typing.Optional[builtins.str] = None,
-                ca_pem: typing.Optional[builtins.str] = None,
-                cert_file: typing.Optional[builtins.str] = None,
-                cert_pem: typing.Optional[builtins.str] = None,
-                consul_token: typing.Optional[builtins.str] = None,
-                headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[str, typing.Any]]]]] = None,
-                http_auth: typing.Optional[builtins.str] = None,
-                ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]] = None,
-                key_file: typing.Optional[builtins.str] = None,
-                key_pem: typing.Optional[builtins.str] = None,
-                region: typing.Optional[builtins.str] = None,
-                secret_id: typing.Optional[builtins.str] = None,
-                vault_token: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fa1135b3e0a6e5d3f7edfef684226a9a3ae7c144ae366e8b37d5ae425d916fff)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = NomadProviderConfig(
@@ -218,8 +197,8 @@ class NomadProvider(
     @jsii.member(jsii_name="headersInput")
     def headers_input(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]], jsii.get(self, "headersInput"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]], jsii.get(self, "headersInput"))
 
     @builtins.property
     @jsii.member(jsii_name="httpAuthInput")
@@ -230,8 +209,8 @@ class NomadProvider(
     @jsii.member(jsii_name="ignoreEnvVarsInput")
     def ignore_env_vars_input(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]]:
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]], jsii.get(self, "ignoreEnvVarsInput"))
+    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]]:
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]], jsii.get(self, "ignoreEnvVarsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="keyFileInput")
@@ -266,9 +245,7 @@ class NomadProvider(
     @address.setter
     def address(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0beabfec8d7dd5d694d2cef5d7bc866119587940ba297f965ed9e5822f413b7a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "address", value)
 
@@ -280,9 +257,7 @@ class NomadProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7e5de19b3060e54bb9c7fdcfe267e89508ed0eb9eb0184bd9cd17c3d40a7169d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -294,9 +269,7 @@ class NomadProvider(
     @ca_file.setter
     def ca_file(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9aff273426dc241a2eb068c671e754330aaf4caecdbac2821e45b146e780d272)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "caFile", value)
 
@@ -308,9 +281,7 @@ class NomadProvider(
     @ca_pem.setter
     def ca_pem(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__65ff0fb31e2b5251e5cdbef8c962770de40031fdafb80d09b48167b6a056bded)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "caPem", value)
 
@@ -322,9 +293,7 @@ class NomadProvider(
     @cert_file.setter
     def cert_file(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bf67e2c037b05499cfe0245de807dc78ac7dfd606e54bef3181c717ce8f027d2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "certFile", value)
 
@@ -336,9 +305,7 @@ class NomadProvider(
     @cert_pem.setter
     def cert_pem(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9a34464dbc144eb2214380e5db8e2a958ee7a2b5c2f109aa24fbbf20d538fd2e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "certPem", value)
 
@@ -350,9 +317,7 @@ class NomadProvider(
     @consul_token.setter
     def consul_token(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__30489e475fdf34de0e156c791593eaf7fd8fde64fd18bbb6289f36d1cdb9098c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "consulToken", value)
 
@@ -360,20 +325,16 @@ class NomadProvider(
     @jsii.member(jsii_name="headers")
     def headers(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]], jsii.get(self, "headers"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]], jsii.get(self, "headers"))
 
     @headers.setter
     def headers(
         self,
-        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7a3f592752af918242782f6ea70217202671f5edcc341fcf80f1cbb08d18bac6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "headers", value)
 
@@ -385,9 +346,7 @@ class NomadProvider(
     @http_auth.setter
     def http_auth(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c66bf4bc162a7eec972510b0510f85519cabd45b262100f9a2076b2c9e8a8c13)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "httpAuth", value)
 
@@ -395,20 +354,16 @@ class NomadProvider(
     @jsii.member(jsii_name="ignoreEnvVars")
     def ignore_env_vars(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]]:
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]], jsii.get(self, "ignoreEnvVars"))
+    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]]:
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]], jsii.get(self, "ignoreEnvVars"))
 
     @ignore_env_vars.setter
     def ignore_env_vars(
         self,
-        value: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]],
+        value: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__49719b0f0dbe22ef93291f5e0a62835d823f044ce61032f370f1ba1cba2868f2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ignoreEnvVars", value)
 
@@ -420,9 +375,7 @@ class NomadProvider(
     @key_file.setter
     def key_file(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__468babcbbdb16e5670b21e9f8eba58d5bcd8045ca7ed476d317c655d74c133dd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keyFile", value)
 
@@ -434,9 +387,7 @@ class NomadProvider(
     @key_pem.setter
     def key_pem(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__85cd3c41f2552a4146e96aabcb245bb4299fffa94adf0880356e26445462328d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keyPem", value)
 
@@ -448,9 +399,7 @@ class NomadProvider(
     @region.setter
     def region(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b04a884d329f7dcafe6ca5f0f57fbab564e8d3bb90b7b3efb1f5d2b2ec4d60a7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "region", value)
 
@@ -462,9 +411,7 @@ class NomadProvider(
     @secret_id.setter
     def secret_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a02d46d72fb1046bdbb99d51171a00c00913f2085971c13e6a975aa870e3694b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretId", value)
 
@@ -476,9 +423,7 @@ class NomadProvider(
     @vault_token.setter
     def vault_token(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6c35027298099735fca65479f06bd9ef7c18a82b71e2e6c73f48e0b6327262c6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vaultToken", value)
 
@@ -515,9 +460,9 @@ class NomadProviderConfig:
         cert_file: typing.Optional[builtins.str] = None,
         cert_pem: typing.Optional[builtins.str] = None,
         consul_token: typing.Optional[builtins.str] = None,
-        headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[str, typing.Any]]]]] = None,
+        headers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[builtins.str, typing.Any]]]]] = None,
         http_auth: typing.Optional[builtins.str] = None,
-        ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]] = None,
+        ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]] = None,
         key_file: typing.Optional[builtins.str] = None,
         key_pem: typing.Optional[builtins.str] = None,
         region: typing.Optional[builtins.str] = None,
@@ -542,26 +487,7 @@ class NomadProviderConfig:
         :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#vault_token NomadProvider#vault_token}
         '''
         if __debug__:
-            def stub(
-                *,
-                address: builtins.str,
-                alias: typing.Optional[builtins.str] = None,
-                ca_file: typing.Optional[builtins.str] = None,
-                ca_pem: typing.Optional[builtins.str] = None,
-                cert_file: typing.Optional[builtins.str] = None,
-                cert_pem: typing.Optional[builtins.str] = None,
-                consul_token: typing.Optional[builtins.str] = None,
-                headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[str, typing.Any]]]]] = None,
-                http_auth: typing.Optional[builtins.str] = None,
-                ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]] = None,
-                key_file: typing.Optional[builtins.str] = None,
-                key_pem: typing.Optional[builtins.str] = None,
-                region: typing.Optional[builtins.str] = None,
-                secret_id: typing.Optional[builtins.str] = None,
-                vault_token: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e759273490438086fe5dd3d88c084b63217b1cc6e133fcd010a5f3e4c7a37ada)
             check_type(argname="argument address", value=address, expected_type=type_hints["address"])
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument ca_file", value=ca_file, expected_type=type_hints["ca_file"])
@@ -577,7 +503,7 @@ class NomadProviderConfig:
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument secret_id", value=secret_id, expected_type=type_hints["secret_id"])
             check_type(argname="argument vault_token", value=vault_token, expected_type=type_hints["vault_token"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "address": address,
         }
         if alias is not None:
@@ -676,13 +602,13 @@ class NomadProviderConfig:
     @builtins.property
     def headers(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]]:
         '''headers block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#headers NomadProvider#headers}
         '''
         result = self._values.get("headers")
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]], result)
 
     @builtins.property
     def http_auth(self) -> typing.Optional[builtins.str]:
@@ -696,13 +622,13 @@ class NomadProviderConfig:
     @builtins.property
     def ignore_env_vars(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]]:
         '''A set of environment variables that are ignored by the provider when configuring the Nomad API client.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ignore_env_vars NomadProvider#ignore_env_vars}
         '''
         result = self._values.get("ignore_env_vars")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]], result)
 
     @builtins.property
     def key_file(self) -> typing.Optional[builtins.str]:
@@ -773,12 +699,10 @@ class NomadProviderHeaders:
         :param value: The header value. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#value NomadProvider#value}
         '''
         if __debug__:
-            def stub(*, name: builtins.str, value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__55e77394e5bf2f9bd34a37f003dbe588118fddb6f74338ed48dcede78167deb3)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "value": value,
         }
@@ -822,3 +746,145 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__fa1135b3e0a6e5d3f7edfef684226a9a3ae7c144ae366e8b37d5ae425d916fff(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    address: builtins.str,
+    alias: typing.Optional[builtins.str] = None,
+    ca_file: typing.Optional[builtins.str] = None,
+    ca_pem: typing.Optional[builtins.str] = None,
+    cert_file: typing.Optional[builtins.str] = None,
+    cert_pem: typing.Optional[builtins.str] = None,
+    consul_token: typing.Optional[builtins.str] = None,
+    headers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[NomadProviderHeaders, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    http_auth: typing.Optional[builtins.str] = None,
+    ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]] = None,
+    key_file: typing.Optional[builtins.str] = None,
+    key_pem: typing.Optional[builtins.str] = None,
+    region: typing.Optional[builtins.str] = None,
+    secret_id: typing.Optional[builtins.str] = None,
+    vault_token: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0beabfec8d7dd5d694d2cef5d7bc866119587940ba297f965ed9e5822f413b7a(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7e5de19b3060e54bb9c7fdcfe267e89508ed0eb9eb0184bd9cd17c3d40a7169d(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9aff273426dc241a2eb068c671e754330aaf4caecdbac2821e45b146e780d272(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__65ff0fb31e2b5251e5cdbef8c962770de40031fdafb80d09b48167b6a056bded(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bf67e2c037b05499cfe0245de807dc78ac7dfd606e54bef3181c717ce8f027d2(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9a34464dbc144eb2214380e5db8e2a958ee7a2b5c2f109aa24fbbf20d538fd2e(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__30489e475fdf34de0e156c791593eaf7fd8fde64fd18bbb6289f36d1cdb9098c(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7a3f592752af918242782f6ea70217202671f5edcc341fcf80f1cbb08d18bac6(
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[NomadProviderHeaders]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c66bf4bc162a7eec972510b0510f85519cabd45b262100f9a2076b2c9e8a8c13(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__49719b0f0dbe22ef93291f5e0a62835d823f044ce61032f370f1ba1cba2868f2(
+    value: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__468babcbbdb16e5670b21e9f8eba58d5bcd8045ca7ed476d317c655d74c133dd(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__85cd3c41f2552a4146e96aabcb245bb4299fffa94adf0880356e26445462328d(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b04a884d329f7dcafe6ca5f0f57fbab564e8d3bb90b7b3efb1f5d2b2ec4d60a7(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a02d46d72fb1046bdbb99d51171a00c00913f2085971c13e6a975aa870e3694b(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6c35027298099735fca65479f06bd9ef7c18a82b71e2e6c73f48e0b6327262c6(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e759273490438086fe5dd3d88c084b63217b1cc6e133fcd010a5f3e4c7a37ada(
+    *,
+    address: builtins.str,
+    alias: typing.Optional[builtins.str] = None,
+    ca_file: typing.Optional[builtins.str] = None,
+    ca_pem: typing.Optional[builtins.str] = None,
+    cert_file: typing.Optional[builtins.str] = None,
+    cert_pem: typing.Optional[builtins.str] = None,
+    consul_token: typing.Optional[builtins.str] = None,
+    headers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[NomadProviderHeaders, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    http_auth: typing.Optional[builtins.str] = None,
+    ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]] = None,
+    key_file: typing.Optional[builtins.str] = None,
+    key_pem: typing.Optional[builtins.str] = None,
+    region: typing.Optional[builtins.str] = None,
+    secret_id: typing.Optional[builtins.str] = None,
+    vault_token: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__55e77394e5bf2f9bd34a37f003dbe588118fddb6f74338ed48dcede78167deb3(
+    *,
+    name: builtins.str,
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
